﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Pivot.Core;

namespace RadPivotGrid_PersistExpandState_WPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        internal Dictionary<IGroup, bool> groupsState;
        public MainWindow()
        {
            InitializeComponent();
            this.groupsState = new Dictionary<IGroup, bool>();
        }
        private void GetCollapsedRowGroups(IEnumerable<IGroup> groups)
        {
            foreach (var gr in groups)
            {
                var isCollapsed = this.radPivotGrid.IsRowCollapsed(gr);

                this.groupsState.Add(gr, isCollapsed);

                if (gr.Type != GroupType.BottomLevel)
                {
                    this.GetCollapsedRowGroups(gr.Groups);
                }
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            this.groupsState.Clear();
            this.GetCollapsedRowGroups(this.radPivotGrid.RowGroups);

            (this.radPivotGrid.DataProvider as LocalDataSourceProvider).ItemsSource = new AllOrders();
            this.radPivotGrid.DataProvider.BlockUntilRefreshCompletes();
            Dispatcher.BeginInvoke(new Action(() => this.RestoreRowsCollapsedState()));
        }

        private void RestoreRowsCollapsedState()
        {
            foreach (var group in groupsState)
            {
                if (group.Value)
                {
                    ///You can add check if such group (group.Key) exist in RadPivotGrid
                    ///As the groups in RadPivotGrid are new and they will not match if the 
                    ///comparison is direct with our saved groups, we have to find the matching group based on the values of its properties
                    var gr = (this.radPivotGrid.RowGroups.Where(p => p.Name == group.Key.Name && p.Level == group.Key.Level && p.Type == group.Key.Type)).FirstOrDefault<IGroup>();
                    
                    if (gr != null)
                    {
                        this.radPivotGrid.CollapseRow(gr);
                    }
                }
                else
                {
                    ///You can add check if such group(group.Key) exist in RadPivotGrid
                    ///
                    ///As the groups in RadPivotGrid are new and they will not match if the 
                    ///comparison is direct with our saved groups, we have to find the matching group based on the values of its properties
                    var gr = (this.radPivotGrid.RowGroups.Where(p => p.Name == group.Key.Name && p.Level == group.Key.Level && p.Type == group.Key.Type)).FirstOrDefault<IGroup>();
                   
                    if (gr != null)
                    {
                        this.radPivotGrid.ExpandRow(gr);
                    }
                }
            }

        }
    }
}
